@@ -3,10 +3,10 @@
 
 import time
 import board
-import adafruit_msa301
+from adafruit_msa3xx import MSA301
 
 i2c = board.I2C()  # uses board.SCL and board.SDA
-msa = adafruit_msa301.MSA301(i2c)
+msa = MSA301(i2c)
 
 msa.enable_tap_detection()
 
